Coverage for C:\src\imod-python\imod\flow\rch.py: 100%

1 from imod.flow.pkgbase import TopBoundaryCondition

2

3

4 class Recharge(TopBoundaryCondition):

5 """

6 Recharge provides a fixed flux boundary condition to the top layer of the

7 groundwater system. Note that unlike in iMOD-WQ, there is only the option

8 in iMODFLOW to apply the recharge package to the top layer.

9

10 Parameters

11 ----------

12 rate: float or xr.DataArray of floats

13 recharge rate in mm/day (NOTA BENE!), dims ``("time", "y", "x")``.

14 """

15

16 _pkg_id = "rch"

17 _variable_order = ["rate"]

18

19 def __init__(self, rate):

20 super().__init__()

21 self.dataset["rate"] = rate